check

Function check 

pub fn check(name: &str) -> Result<(), String>
Check if a failpoint is set and execute its action. Returns Ok(()) if no failpoint or Off, Err if Error action.

Panics

Panics if the internal registry mutex is poisoned, or if the failpoint action is Panic.