PatchValue

Enum PatchValue 

pub enum PatchValue {
    Add {
        blob: GitOid,
        file_id: FileId,
    },
    Delete {
        previous_blob: GitOid,
        file_id: FileId,
    },
    Modify {
        base_blob: GitOid,
        new_blob: GitOid,
        file_id: FileId,
    },
    Rename {
        from: PathBuf,
        file_id: FileId,
        new_blob: Option<GitOid>,
    },
}
The change applied to a single path within a PatchSet (5.4).

Serialized with a "op" tag for canonical JSON: {"op":"add","blob":"…","file_id":"…"} etc.

Variants



Add

File was created at this path.

Fields

blob: GitOid

Blob OID for the new file content.

file_id: FileId

Stable identity assigned at file creation.



Delete

File was removed from this path.

Fields

previous_blob: GitOid

Blob OID the file had before deletion (needed for undo).

file_id: FileId

Stable identity of the deleted file.



Modify

File content was changed in place.

Fields

base_blob: GitOid

Blob OID the file had before the modification (needed for undo).

new_blob: GitOid

Blob OID for the new file content.

file_id: FileId

Stable file identity (unchanged by a modify).



Rename

File was moved (and optionally also modified).

The path key in PatchSet::patches is the destination path. from records the source path.

Fields

from: PathBuf

Source path the file was moved from.

file_id: FileId

Stable file identity (unchanged by a rename).

new_blob: Option<GitOid>

New blob OID if the content was also changed during the rename. None means the content is identical to the epoch’s blob.