pub enum WorkspaceMode {
Ephemeral,
Persistent,
}Expand description
The lifetime mode of a workspace.
- Ephemeral (default): Created from the current epoch, must be merged or destroyed before the next epoch advance. Warns if it survives epochs.
- Persistent (opt-in): Can survive across epochs. Supports explicit
maw ws advance <name>to rebase onto the latest epoch.
Variants
Ephemeral
Default: workspace should be merged or destroyed before epoch advances.
Persistent
Opt-in: workspace can survive across epochs; advance explicitly.
Implementations
Sourceimpl WorkspaceMode
impl WorkspaceMode
Sourcepub const fn is_persistent(&self) -> bool
pub const fn is_persistent(&self) -> bool
Returns true if this is a persistent workspace.
Sourcepub const fn is_ephemeral(&self) -> bool
pub const fn is_ephemeral(&self) -> bool
Returns true if this is an ephemeral workspace.