pub enum WorkspaceState {
Active,
Stale {
behind_epochs: u32,
},
Destroyed,
}Expand description
The state of a workspace relative to the current epoch.
Variants
Active
Workspace is up-to-date with the current epoch.
Stale
Workspace is behind the current epoch by some number of epochs.
Destroyed
Workspace has been destroyed (metadata retained for history).
Implementations