pub struct WorkspaceInfo {
pub id: WorkspaceId,
pub path: PathBuf,
pub epoch: EpochId,
pub state: WorkspaceState,
pub mode: WorkspaceMode,
pub commits_ahead: u32,
}Expand description
Complete information about a workspace.
Fields
id: WorkspaceIdUnique workspace identifier.
path: PathBufAbsolute path to the workspace root directory.
epoch: EpochIdThe epoch this workspace is based on (or the workspace HEAD if ahead of epoch).
state: WorkspaceStateCurrent state of the workspace.
mode: WorkspaceModeLifetime mode: ephemeral (default) or persistent.
commits_ahead: u32Number of commits in the workspace that are ahead of the current epoch. Non-zero means the workspace has committed work that hasn’t been merged yet.