pub struct Config { /* private fields */ }Implementations
Sourceimpl Config
impl Config
Sourcepub fn body_limit(self, limit: usize) -> Self
pub fn body_limit(self, limit: usize) -> Self
Set the maximum body size that the server accepts
Default: 4MB
Sourcepub fn proxy_header(self, header: impl Into<String>) -> Self
pub fn proxy_header(self, header: impl Into<String>) -> Self
ProxyHeader will enable c.req.ip() to return the value of the given header key By default c.req.ip() will return the Remote IP from the TCP connection This property can be useful if you are behind a load balancer: X-Forwarded-* NOTE: headers are easily spoofed and the detected IP addresses are unreliable.
Default: “”